@@ -11,19 +11,16 @@ surv_CV <-
            predict_function,
            model_args = list(),
            predict_args = list(),
-           model_name = "my model") {
-
-    if (!is.null(model_args$max_grid_size)) {
-      max_grid_size = model_args$max_grid_size
-    } else{
-      max_grid_size = NaN
-    }
-
+           model_name = "my model",
+           impute = 0,
+           impute_method = "missForest") {
     time_0 <- Sys.time()
 
     if (is.nan(fixed_time)) {fixed_time <-quantile(df[df$event == 1, "time"], 0.9, na.rm = TRUE)}
     if (is.nan(randomseed)) {randomseed <- round(stats::runif(1) * 1e9, 0)}
-
+    if (!is.null(model_args$max_grid_size)) { 
+      max_grid_size = model_args$max_grid_size } else{ max_grid_size = NaN }
+    
     if (!any(is.data.frame(df),
       predict.factors %in% colnames(df),
       c("time", "event") %in% colnames(df)
@@ -31,15 +28,18 @@ surv_CV <-
       stop("Data should be a data frame, predictors
            should correspond to the columns.")
     }
-    if (sum(is.na(df[c("time", "event", predict.factors)])) > 0) {
-      stop("Missing data can not be handled. Please impute first.")
-    }
     predict.factors <- eligible_params(predict.factors, df)
     if (length(predict.factors) == 0) {
       print("No eligible params")
       return(NULL)
     }
     Call <- match.call()
+    
+    # Missing data handling
+    if (sum(is.na(df[c("time", "event", predict.factors)])) > 0){ 
+      df = missing_data_handle(df, predict.factors, impute)
+      }
+    
     #defining number of repeated cv
     if (is.null(repeat_cv)) {      repeat_cv = 1    }
     if (is.numeric(repeat_cv) & repeat_cv > 1) {
@@ -62,13 +62,21 @@ surv_CV <-
       cv_folds <- caret::createFolds(df$event, k = outer_cv, list = FALSE)
 
       # cross-validation loop:
-      pb <- utils::txtProgressBar(0, outer_cv, style = 3)# progress bar
+      pb <- utils::txtProgressBar(0, outer_cv, style = 3) # progress bar
       for (cv_iteration in 1:outer_cv) {
         utils::setTxtProgressBar(pb, cv_iteration) #progress bar update
         df_train_cv <- df[cv_folds != cv_iteration,]
         df_test_cv <- df[cv_folds == cv_iteration,]
+        
+        # impute train and test if impute == 1 and there are missing values 
+        if (impute == 1){
+          temp = impute1(df_train_cv, df_test_cv, predict.factors)
+          df_train_cv = temp$train
+          df_test_cv = temp$test
+          remove(temp)
+        }
         predict.factors.cv <- eligible_params(predict.factors, df_train_cv)
-
+        
         # tune the model using train_function
         trained_model <-
           do.call(train_function,
@@ -180,12 +188,9 @@ surv_CV <-
     output$test <- df_modelstats_test
     output$train <- df_modelstats_train
     output$test_pooled <- pooled_test(df_modelstats_test)
-    output$testaverage <-
-      sapply(df_modelstats_test, mean, na.rm = TRUE)
-    output$testmedian <-
-      sapply(df_modelstats_test, median, na.rm = TRUE)
-    output$trainaverage <-
-      sapply(df_modelstats_train, mean, na.rm = TRUE)
+    output$testaverage <- sapply(df_modelstats_test, mean, na.rm = TRUE)
+    output$testmedian <- sapply(df_modelstats_test, median, na.rm = TRUE)
+    output$trainaverage <- sapply(df_modelstats_train, mean, na.rm = TRUE)
     output$tuned_cv_models <- models_for_each_cv
     output$randomseed <- randomseed
     output$bestparams<- bestparams
@@ -201,3 +206,63 @@ surv_CV <-
     print(time_1 - time_0)
     return(output)
   }
+
+impute1 <- 
+  function(df_train, df_test, predict.factors) {
+  miss_train = sum(is.na(df_train[predict.factors]))
+  miss_test = sum(is.na(df_test[ predict.factors]))
+  if (miss_train > 0 | miss_test > 0) {
+    mf = missForestPredict::missForest(
+      df_train[predict.factors], save_models = TRUE,
+      num.trees = 100, maxiter = 5, verbose = FALSE)
+    df_train[predict.factors] = mf$ximp
+    if (miss_test > 0) {
+      df_test[predict.factors] = 
+        missForestPredict::missForestPredict(
+          mf, newdata = df_test[predict.factors])
+    }
+  }
+  output = list()
+  output$train = df_train
+  output$test = df_test
+  return (output)
+}
+
+missing_data_handle <- function(df, predict.factors, impute){
+  msg0 <- "Set 'impute' to 0 for no imputation, 1 for proper imputation by missForest, 2 for fast imputation by missForest, 3 for complete cases."
+  # If impute = 0, then there is no imputation, we stop with a message.
+  if (impute == 0) {
+    stop(paste("Some data are missing. By default ('impute' = 0), no imputation is performed.", msg0))
+  }
+  # If impute = 3, then analyse complete cases.
+  if (impute == 3) {
+    msg3 =  "Some data are missing, 'impute' is set to 3 for complete cases analysis."
+    print(paste(msg3, msg0))
+    print(paste("Share of complete cases = ", round(mean(complete.cases(df)),2)))
+    df <- df[complete.cases(df), ]
+    return(df)
+  }
+  # If impute = 2, then we impute first, then perform all validations
+  if (impute == 2) {
+    msg2 <- "Some data are missing, 'impute' is set to 2 for fast imputation (impute all the data, then cross-validate)."
+    print(paste(msg2,msg0))
+    temp <-
+      missForestPredict::missForest(
+        df[c("time", "event", predict.factors)],
+        save_models = FALSE,
+        maxiter = 5,
+        num.trees = 100,
+        verbose = FALSE
+      )
+    df = temp$ximp
+    remove(temp)
+    return(df)
+  }
+  # If impute = 2, then we impute properly, train, then test. Only information message here
+  if (impute == 1) {
+    msg1 <- "Some data are missing, 'impute' is set to 1 for proper imputation (impute train, then test for each data split)."
+    print(paste(msg1,msg0))
+    return(df)
+  }
+  return(df)
+}
\ No newline at end of file
